@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::config;
-$Footprintless::App::Command::config::VERSION = '1.12';
+$Footprintless::App::Command::config::VERSION = '1.13';
 # ABSTRACT: Prints the config at the coordinate.
 # PODNAME: Footprintless::App::Command::config
 
@@ -89,7 +89,7 @@ sub opt_spec {
 }
 
 sub usage_desc {
-    return "fpl %o [COORDINATE]";
+    return "fpl config [COORDINATE] %o";
 }
 
 sub validate_args {
@@ -108,7 +108,7 @@ Footprintless::App::Command::config - Prints the config at the coordinate.
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
