@@ -2,20 +2,25 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::deployment;
-$Footprintless::App::Command::deployment::VERSION = '1.12';
+$Footprintless::App::Command::deployment::VERSION = '1.13';
 # ABSTRACT: Performs an action on a deployment.
 # PODNAME: Footprintless::App::Command::deployment
 
 use parent qw(Footprintless::App::ActionCommand);
 
-my %actions = (
-    'clean'  => 'Footprintless::App::Command::deployment::clean',
-    'deploy' => 'Footprintless::App::Command::deployment::deploy'
-);
+sub _actions {
+    return (
+        'clean'  => 'Footprintless::App::Command::deployment::clean',
+        'deploy' => 'Footprintless::App::Command::deployment::deploy'
+    );
+}
 
-sub _action_implementation {
-    my ( $self, $action ) = @_;
-    return $actions{$action};
+sub _default_action {
+    return 'deploy';
+}
+
+sub usage_desc {
+    return "fpl deployment DEPLOYMENT_COORD ACTION %o";
 }
 
 1;
@@ -30,20 +35,17 @@ Footprintless::App::Command::deployment - Performs an action on a deployment.
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
-    fpl deployment project.environment.component.deployment clean
-    fpl deployment project.environment.component.deployment deploy
-    fpl deployment project.environment.component.deployment deploy --clean
+    fpl deployment DEPLOYMENT_COORD clean
+    fpl deployment DEPLOYMENT_COORD deploy
+    fpl deployment DEPLOYMENT_COORD deploy --clean
 
 =head1 DESCRIPTION
 
-Performs actions on a deployment. The available actions are:
-
-    clean   removes all files/folders handled by this deployment
-    deploy  deploys all the resources handled by this deployment
+Performs actions on a deployment.
 
 =head1 AUTHOR
 
