@@ -2,7 +2,10 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::deployment::deploy;
-$Footprintless::App::Command::deployment::deploy::VERSION = '1.12';
+$Footprintless::App::Command::deployment::deploy::VERSION = '1.13';
+# ABSTRACT: deploys all files managed by the deployment
+# PODNAME: Footprintless::App::Command::deployment::deploy
+
 use parent qw(Footprintless::App::Action);
 
 use Footprintless::App -ignore;
@@ -11,7 +14,7 @@ use Log::Any;
 my $logger = Log::Any->get_logger();
 
 sub execute {
-    my ( $self, $footprintless, $coordinate, $opts, $args ) = @_;
+    my ( $self, $opts, $args ) = @_;
 
     if ( $opts->{clean} ) {
         $logger->info('Performing clean...');
@@ -28,15 +31,15 @@ sub opt_spec {
 }
 
 sub usage_desc {
-    return "fpl deployment [COORDINATE] deploy [OPTIONS]";
+    return "fpl deployment DEPLOYMENT_COORD deploy %o";
 }
 
 sub validate_args {
-    my ( $self, $footprintless, $coordinate, $opts, $args ) = @_;
+    my ( $self, $opts, $args ) = @_;
 
-    eval { $self->{deployment} = $footprintless->deployment($coordinate); };
+    eval { $self->{deployment} = $self->{footprintless}->deployment( $self->{coordinate} ); };
 
-    $self->usage_error("invalid coordinate [$coordinate]: $@") if ($@);
+    $self->usage_error("invalid coordinate [$self->{coordinate}]: $@") if ($@);
 }
 
 1;
@@ -47,11 +50,11 @@ __END__
 
 =head1 NAME
 
-Footprintless::App::Command::deployment::deploy
+Footprintless::App::Command::deployment::deploy - deploys all files managed by the deployment
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 AUTHOR
 
