@@ -2,23 +2,28 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::log;
-$Footprintless::App::Command::log::VERSION = '1.12';
+$Footprintless::App::Command::log::VERSION = '1.13';
 # ABSTRACT: Provides access to log files.
 # PODNAME: Footprintless::App::Command::log
 
 use parent qw(Footprintless::App::ActionCommand);
 
-my %actions = (
-    'cat'    => 'Footprintless::App::Command::log::cat',
-    'follow' => 'Footprintless::App::Command::log::follow',
-    'grep'   => 'Footprintless::App::Command::log::grep',
-    'head'   => 'Footprintless::App::Command::log::head',
-    'tail'   => 'Footprintless::App::Command::log::tail',
-);
+sub _actions {
+    return (
+        'cat'    => 'Footprintless::App::Command::log::cat',
+        'follow' => 'Footprintless::App::Command::log::follow',
+        'grep'   => 'Footprintless::App::Command::log::grep',
+        'head'   => 'Footprintless::App::Command::log::head',
+        'tail'   => 'Footprintless::App::Command::log::tail'
+    );
+}
 
-sub _action_implementation {
-    my ( $self, $action ) = @_;
-    return $actions{$action};
+sub _default_action {
+    return 'follow';
+}
+
+sub usage_desc {
+    return "fpl log LOG_COORD ACTION %o";
 }
 
 1;
@@ -33,7 +38,7 @@ Footprintless::App::Command::log - Provides access to log files.
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
@@ -42,14 +47,7 @@ version 1.12
 
 =head1 DESCRIPTION
 
-Provides various forms of read access to log files.  The available actions 
-are:
-
-    cat      read the entire file
-    follow   essentially tail -f
-    grep     search for specific content in the file
-    head     read from the beginning of the file
-    tail     read from the end of the file
+Provides various forms of read access to log files.
 
 =head1 AUTHOR
 
