@@ -2,7 +2,10 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::log::grep;
-$Footprintless::App::Command::log::grep::VERSION = '1.12';
+$Footprintless::App::Command::log::grep::VERSION = '1.13';
+# ABSTRACT: output lines matching a pattern
+# PODNAME: Footprintless::App::Command::log::grep
+
 use parent qw(Footprintless::App::Action);
 
 use Footprintless::App -ignore;
@@ -11,7 +14,7 @@ use Log::Any;
 my $logger = Log::Any->get_logger();
 
 sub execute {
-    my ( $self, $footprintless, $coordinate, $opts, $args ) = @_;
+    my ( $self, $opts, $args ) = @_;
 
     $self->{log}->grep(
         runner_options => { out_handle => \*STDOUT },
@@ -25,11 +28,15 @@ sub opt_spec {
     return ( [ 'arg=s@', 'an argument passed to the command' ] );
 }
 
-sub validate_args {
-    my ( $self, $footprintless, $coordinate, $opts, $args ) = @_;
+sub usage_desc {
+    return "fpl log LOG_COORD grep %o";
+}
 
-    eval { $self->{log} = $footprintless->log($coordinate); };
-    $self->usage_error("invalid coordinate [$coordinate]: $@") if ($@);
+sub validate_args {
+    my ( $self, $opts, $args ) = @_;
+
+    eval { $self->{log} = $self->{footprintless}->log( $self->{coordinate} ); };
+    $self->usage_error("invalid coordinate [$self->{coordinate}]: $@") if ($@);
 }
 
 1;
@@ -40,11 +47,11 @@ __END__
 
 =head1 NAME
 
-Footprintless::App::Command::log::grep
+Footprintless::App::Command::log::grep - output lines matching a pattern
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 AUTHOR
 
