@@ -2,7 +2,10 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::overlay::initialize;
-$Footprintless::App::Command::overlay::initialize::VERSION = '1.12';
+$Footprintless::App::Command::overlay::initialize::VERSION = '1.13';
+# ABSTRACT: cleans, then processes the overlay base and template files
+# PODNAME: Footprintless::App::Command::overlay::initialize
+
 use parent qw(Footprintless::App::Action);
 
 use Footprintless::App -ignore;
@@ -11,7 +14,7 @@ use Log::Any;
 my $logger = Log::Any->get_logger();
 
 sub execute {
-    my ( $self, $footprintless, $coordinate, $opts, $args ) = @_;
+    my ( $self, $opts, $args ) = @_;
 
     $logger->info('Performing initialize...');
     $self->{overlay}->initialize();
@@ -20,15 +23,15 @@ sub execute {
 }
 
 sub usage_desc {
-    return "fpl overlay [COORDINATE] initialize [OPTIONS]";
+    return "fpl overlay OVERLAY_COORD initialize %o";
 }
 
 sub validate_args {
-    my ( $self, $footprintless, $coordinate, $opts, $args ) = @_;
+    my ( $self, $opts, $args ) = @_;
 
-    eval { $self->{overlay} = $footprintless->overlay($coordinate); };
+    eval { $self->{overlay} = $self->{footprintless}->overlay( $self->{coordinate} ); };
 
-    $self->usage_error("invalid coordinate [$coordinate]: $@") if ($@);
+    $self->usage_error("invalid coordinate [$self->{coordinate}]: $@") if ($@);
 }
 
 1;
@@ -39,11 +42,11 @@ __END__
 
 =head1 NAME
 
-Footprintless::App::Command::overlay::initialize
+Footprintless::App::Command::overlay::initialize - cleans, then processes the overlay base and template files
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 AUTHOR
 
