@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::service;
-$Footprintless::App::Command::service::VERSION = '1.12';
+$Footprintless::App::Command::service::VERSION = '1.13';
 use Footprintless::App -command;
 use Footprintless::Util qw(exit_due_to);
 use Log::Any;
@@ -16,10 +16,6 @@ sub execute {
     my ( $self, $opts, $args ) = @_;
     my ( $coordinate, $action ) = @$args;
 
-    if ( $opts->{log} ) {
-        $self->_configure_logging( $opts->{log} );
-    }
-
     $logger->debugf( 'executing %s for %s', $action, $coordinate );
     eval { $self->{service}->execute($action); };
     if ($@) {
@@ -31,7 +27,7 @@ sub execute {
 }
 
 sub usage_desc {
-    return "fpl service [COORDINATE] [ACTION] %o";
+    return "fpl service SERVICE_COORD ACTION";
 }
 
 sub validate_args {
@@ -65,7 +61,7 @@ Footprintless::App::Command::service - Performs an action on a service.
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
@@ -76,14 +72,17 @@ version 1.12
 
 =head1 DESCRIPTION
 
-Performs actions on a service.  The default actions are:
+Performs actions on a service.  
 
-    kill - kills the service abruptly
-    start - starts the service
-    status - checks the status of the service (running/stopped)
-    stop - stops the service
+Base actions:
 
-For detail action configuration see L<Footprintless::Service>. 
+    kill: kills the service abruptly
+   start: starts the service
+  status: checks the status of the service (running/stopped)
+    stop: stops the service
+
+Additional actions can be defined by your entity based on the service 
+commands actual capabilities.
 
 =head1 AUTHOR
 
