@@ -2,7 +2,10 @@ use strict;
 use warnings;
 
 package Footprintless::MixableBase;
-$Footprintless::MixableBase::VERSION = '1.12';
+$Footprintless::MixableBase::VERSION = '1.13';
+# ABSTRACT: A base class for using mixins
+# PODNAME: Footprintless::MixableBase
+
 use Log::Any;
 
 my $logger = Log::Any->get_logger();
@@ -32,11 +35,11 @@ __END__
 
 =head1 NAME
 
-Footprintless::MixableBase
+Footprintless::MixableBase - A base class for using mixins
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
