@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Mixins;
-$Footprintless::Mixins::VERSION = '1.12';
+$Footprintless::Mixins::VERSION = '1.13';
 # ABSTRACT: A utility package for mixins for standard object
 # PODNAME: Footprintless::Mixins
 
@@ -92,7 +92,7 @@ sub _download {
 sub _entity {
     my ( $self, $coordinate, $required ) = @_;
     my $entity = $self->{factory}->entities()->get_entity($coordinate);
-    invalid_entity( $coordinate, "$coordinate required" )
+    invalid_entity( $coordinate, "does not exist" )
         if ( $required && !$entity );
     return $entity;
 }
@@ -225,7 +225,7 @@ Footprintless::Mixins - A utility package for mixins for standard object
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 DESCRIPTION
 
